@@ -53,8 +53,15 @@ if GDK2 or GDK3:
             self.blue = blue
 
         def __eq__(self, other):
+            if not isinstance(other, Gdk.Color):
+                return False
             return self.equal(other)
 
+        # This is required (even when __eq__ is defined) in order
+        # for != operator to work as expected
+        def __ne__(self, other):
+            return not self == other
+
         def __repr__(self):
             return 'Gdk.Color(red=%d, green=%d, blue=%d)' % (self.red, self.green, self.blue)
 
@@ -94,8 +101,15 @@ if GDK3:
             self.alpha = alpha
 
         def __eq__(self, other):
+            if not isinstance(other, Gdk.RGBA):
+                return False
             return self.equal(other)
 
+        # This is required (even when __eq__ is defined) in order
+        # for != operator to work as expected
+        def __ne__(self, other):
+            return not self == other
+
         def __repr__(self):
             return 'Gdk.RGBA(red=%f, green=%f, blue=%f, alpha=%f)' % (self.red, self.green, self.blue, self.alpha)
 
@@ -278,7 +292,7 @@ if GDK2 or GDK3:
                             'EventWindowState',
                             'EventVisibility']
 
-    if Gdk._version == '2.0':
+    if GDK2:
         event_member_classes.append('EventNoExpose')
 
     if hasattr(Gdk, 'EventTouch'):
