@@ -24,6 +24,11 @@
 #include "pygi-ccallback.h"
 #include "pygi-info.h"
 
+/* GI_CHECK_VERSION was introduced in gobject-introspection 1.60 */
+#ifndef GI_CHECK_VERSION
+# define GI_CHECK_VERSION(x,y,z) 0
+#endif
+
 extern PyObject *_PyGIDefaultArgPlaceholder;
 
 typedef struct _PyGICallbackCache
@@ -632,8 +637,13 @@ end:
 
 void _pygi_invoke_closure_free (PyGICClosure* invoke_closure)
 {
+#if GI_CHECK_VERSION (1, 72, 0)
+    g_callable_info_destroy_closure (invoke_closure->info,
+                                     invoke_closure->closure);
+#else
     g_callable_info_free_closure (invoke_closure->info,
                                   invoke_closure->closure);
+#endif
 
     if (invoke_closure->info)
         g_base_info_unref ( (GIBaseInfo*) invoke_closure->info);
@@ -670,9 +680,16 @@ _pygi_make_native_closure (GICallableInfo* info,
     Py_INCREF (py_function);
     Py_XINCREF (closure->user_data);
 
+#if GI_CHECK_VERSION (1, 72, 0)
+    fficlosure =
+        g_callable_info_create_closure (info, &closure->cif, _pygi_closure_handle,
+                                        closure);
+#else
     fficlosure =
         g_callable_info_prepare_closure (info, &closure->cif, _pygi_closure_handle,
                                          closure);
+#endif
+
     closure->closure = fficlosure;
 
     /* Give the closure the information it needs to determine when
@@ -751,7 +768,15 @@ _pygi_marshal_from_py_interface_callback (PyGIInvokeState   *state,
     closure = _pygi_make_native_closure (
         callable_info, callback_cache->closure_cache, callback_cache->scope,
         py_arg, py_user_data);
+
+#if GI_CHECK_VERSION (1, 72, 0)
+    if (closure->closure != NULL)
+        arg->v_pointer = g_callable_info_get_closure_native_address (callable_info, closure->closure);
+    else
+        arg->v_pointer = NULL;
+#else
     arg->v_pointer = closure->closure;
+#endif
 
     /* always decref the user data as _pygi_make_native_closure adds its own ref */
     Py_XDECREF (py_user_data);
